[java-sp-server] branch main updated: GEN-269 - Replace code header

Scott Cantor cantor.2 at osu.edu
Thu Aug 3 12:48:45 UTC 2023


This is an automated email from the git hooks/post-receive script.

scantor pushed a commit to branch main
in repository java-sp-server.

View the commit online:
http://git.shibboleth.net/view/?p=java-sp-server.git;a=commit;h=2d9c8e9ab502dcd6e2b918741a177c17a4ee75d7

The following commit(s) were added to refs/heads/main by this push:
     new 2d9c8e9  GEN-269 - Replace code header
2d9c8e9 is described below

commit 2d9c8e9ab502dcd6e2b918741a177c17a4ee75d7
Author: Scott Cantor <cantor.2 at osu.edu>
AuthorDate: Thu Aug 3 08:47:50 2023 -0400

    GEN-269 - Replace code header
    
    https://shibboleth.atlassian.net/browse/GEN-269
---
 .gitignore                                         | 19 ++-----
 pom.xml                                            |  2 +-
 resources/{ => checkstyle}/checkstyle.xml          |  0
 sp-conf-impl/pom.xml                               |  2 +-
 .../net/shibboleth/sp/conf/services-system.xml     | 23 +--------
 sp-conf/pom.xml                                    |  2 +-
 sp-saml-api/pom.xml                                |  2 +-
 .../config/BrowserSSOProfileConfiguration.java     |  9 ++--
 .../profile/config/SAML2ProfileConfiguration.java  |  9 ++--
 .../config/SingleLogoutProfileConfiguration.java   |  9 ++--
 .../sp/saml/saml2/profile/config/package-info.java |  9 ++--
 sp-saml-impl/pom.xml                               |  2 +-
 ...tSAML2ArtifactConsumerProfileConfiguration.java |  9 ++--
 ...SAML2AssertionConsumerProfileConfiguration.java |  9 ++--
 .../impl/AbstractSAML2ProfileConfiguration.java    |  9 ++--
 .../impl/BrowserSSOProfileConfiguration.java       |  9 ++--
 .../impl/SingleLogoutProfileConfiguration.java     |  9 ++--
 .../saml2/profile/config/impl/package-info.java    |  9 ++--
 .../AbstractSAML2ProfileConfigurationTest.java     |  9 ++--
 .../impl/BrowserSSOProfileConfigurationTest.java   |  9 ++--
 .../impl/SingleLogoutProfileConfigurationTest.java |  9 ++--
 sp-server-api/pom.xml                              |  2 +-
 .../main/java/net/shibboleth/sp/Application.java   | 15 +++---
 .../net/shibboleth/sp/config/package-info.java     |  9 ++--
 .../src/main/java/net/shibboleth/sp/ddf/DDF.java   |  9 ++--
 .../java/net/shibboleth/sp/ddf/DDFSupport.java     |  9 ++--
 .../sp/ddf/RemotedHttpServletRequest.java          |  9 ++--
 .../sp/ddf/RemotedHttpServletResponse.java         |  9 ++--
 .../java/net/shibboleth/sp/ddf/package-info.java   |  9 ++--
 .../java/net/shibboleth/sp/ddf/DDFSupportTest.java |  9 ++--
 .../test/java/net/shibboleth/sp/ddf/DDFTest.java   |  9 ++--
 .../sp/ddf/RemotedHttpServletRequestTest.java      |  9 ++--
 .../sp/ddf/RemotedHttpServletResponseTest.java     |  9 ++--
 sp-server-impl/pom.xml                             |  2 +-
 .../shibboleth/sp/config/impl/package-info.java    |  9 ++--
 .../net/shibboleth/sp/impl/BasicApplication.java   | 58 +++++++++++++++-------
 .../net/shibboleth/sp/impl/OpenSAMLConfigBean.java |  9 ++--
 .../sp/remoting/impl/ReloadingEndpointManager.java |  9 ++--
 .../sp/spring/impl/ByteArrayToDDFConverter.java    |  9 ++--
 .../sp/spring/impl/DDFToByteArrayConverter.java    |  9 ++--
 .../sp/remoting/endpoint/impl/XMLParserTest.java   |  9 ++--
 sp-session-api/pom.xml                             |  2 +-
 .../sp/session/AbstractRemotableSPSession.java     |  9 ++--
 .../shibboleth/sp/session/RemotableSPSession.java  |  9 ++--
 .../java/net/shibboleth/sp/session/SPSession.java  |  9 ++--
 .../shibboleth/sp/session/SessionException.java    |  9 ++--
 .../net/shibboleth/sp/session/package-info.java    |  9 ++--
 sp-session-impl/pom.xml                            |  2 +-
 sp-testing/pom.xml                                 |  2 +-
 49 files changed, 164 insertions(+), 277 deletions(-)

diff --git a/.gitignore b/.gitignore
index d010a23..bf94c29 100644
--- a/.gitignore
+++ b/.gitignore
@@ -1,25 +1,14 @@
 # A simulation of Subversion default ignores, generated by reposurgeon.
-*.o
-*.lo
-*.la
-*.al
-*.libs
-*.so
-*.so.[0-9]*
-*.a
-*.pyc
-*.pyo
-*.rej
-*.iml
 *~
 *.#*
 .*.swp
 .DS_store
 # Simulated Subversion default ignores end here
 # The contents of the svn:ignore property on the branch root.
-/classpath\:
-/test-output
-/target
+classpath\:
+test-output
+target
 .settings
 .project
 .classpath
+.vscode
diff --git a/pom.xml b/pom.xml
index a702ada..173e746 100644
--- a/pom.xml
+++ b/pom.xml
@@ -22,7 +22,7 @@
         <opensaml.version>5.0.0-SNAPSHOT</opensaml.version>
         <shib-shared.version>9.0.0-SNAPSHOT</shib-shared.version>
         <spring-int.version>6.0.1</spring-int.version>
-        <checkstyle.configLocation>${project.basedir}/resources/checkstyle.xml</checkstyle.configLocation>
+        <checkstyle.configLocation>${project.basedir}/resources/checkstyle/checkstyle.xml</checkstyle.configLocation>
     </properties>
     
     <description>
diff --git a/resources/checkstyle.xml b/resources/checkstyle/checkstyle.xml
similarity index 100%
rename from resources/checkstyle.xml
rename to resources/checkstyle/checkstyle.xml
diff --git a/sp-conf-impl/pom.xml b/sp-conf-impl/pom.xml
index 1c049f7..56f8a4a 100644
--- a/sp-conf-impl/pom.xml
+++ b/sp-conf-impl/pom.xml
@@ -15,7 +15,7 @@
     <packaging>jar</packaging>
     
     <properties>
-        <checkstyle.configLocation>${project.basedir}/../resources/checkstyle.xml</checkstyle.configLocation>
+        <checkstyle.configLocation>${project.basedir}/../resources/checkstyle/checkstyle.xml</checkstyle.configLocation>
         <automatic.module.name>net.shibboleth.sp.conf.impl</automatic.module.name>
     </properties>
         
diff --git a/sp-conf-impl/src/main/resources/net/shibboleth/sp/conf/services-system.xml b/sp-conf-impl/src/main/resources/net/shibboleth/sp/conf/services-system.xml
index fd8d42e..ed08100 100644
--- a/sp-conf-impl/src/main/resources/net/shibboleth/sp/conf/services-system.xml
+++ b/sp-conf-impl/src/main/resources/net/shibboleth/sp/conf/services-system.xml
@@ -43,33 +43,12 @@
         p:failFast="%{sp.service.provider.failFast:%{sp.service.failFast:false}}"
         p:reloadCheckDelay="%{sp.service.provider.checkInterval:PT0S}" />
             
-    <!-- Auto-append system config file to resource set. -->
+    <!-- Auto-append system config files to resource set. -->
     <bean id ="ExtendedServiceProviderResources" class="net.shibboleth.shared.spring.factory.CombiningListFactoryBean"
           p:firstList="#{getObject('%{sp.service.provider.resources:shibboleth.ServiceProviderResources}'.trim())}" >
         <property name="secondList">
             <util:list >
                 <value>classpath:/net/shibboleth/sp/conf/endpoints-system.xml</value>
-            </util:list>
-        </property>
-    </bean>
-
-    <!-- Relying Party Service -->
-
-    <bean id="shibboleth.RelyingPartyResolverService" parent="shibboleth.ReloadableService"
-            p:serviceConfigurations-ref="ExtendedRelyingPartyResolverResources"
-            p:failFast="%{sp.service.relyingparty.failFast:%{sp.service.failFast:false}}"
-            p:reloadCheckDelay="%{sp.service.relyingparty.checkInterval:PT0S}">
-        <constructor-arg name="claz" value="net.shibboleth.profile.relyingparty.RelyingPartyConfigurationResolver" />
-        <constructor-arg name="strategy">
-            <bean class="net.shibboleth.shared.spring.service.ClassBasedServiceStrategy"
-                c:serviceableClaz="net.shibboleth.profile.relyingparty.impl.DefaultRelyingPartyConfigurationResolver" />
-        </constructor-arg>
-    </bean>
-    <!-- Auto-append system config file to resource set. -->
-    <bean id ="ExtendedRelyingPartyResolverResources" parent="shibboleth.ListCombiner"
-          p:firstList-ref="#{'%{sp.service.relyingparty.resources:shibboleth.RelyingPartyResolverResources}'.trim()}" >
-        <property name="secondList">
-            <util:list >
                 <value>classpath:/net/shibboleth/sp/conf/relying-party-system.xml</value>
             </util:list>
         </property>
diff --git a/sp-conf/pom.xml b/sp-conf/pom.xml
index 5639322..539e14b 100644
--- a/sp-conf/pom.xml
+++ b/sp-conf/pom.xml
@@ -15,7 +15,7 @@
     <packaging>jar</packaging>
     
     <properties>
-        <checkstyle.configLocation>${project.basedir}/../resources/checkstyle.xml</checkstyle.configLocation>
+        <checkstyle.configLocation>${project.basedir}/../resources/checkstyle/checkstyle.xml</checkstyle.configLocation>
         <automatic.module.name>net.shibboleth.sp.conf</automatic.module.name>
     </properties>
         
diff --git a/sp-saml-api/pom.xml b/sp-saml-api/pom.xml
index d2a972a..9a6f82b 100644
--- a/sp-saml-api/pom.xml
+++ b/sp-saml-api/pom.xml
@@ -15,7 +15,7 @@
     <packaging>jar</packaging>
     
     <properties>
-        <checkstyle.configLocation>${project.basedir}/../resources/checkstyle.xml</checkstyle.configLocation>
+        <checkstyle.configLocation>${project.basedir}/../resources/checkstyle/checkstyle.xml</checkstyle.configLocation>
         <automatic.module.name>net.shibboleth.sp.saml</automatic.module.name>
     </properties>
         
diff --git a/sp-saml-api/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/BrowserSSOProfileConfiguration.java b/sp-saml-api/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/BrowserSSOProfileConfiguration.java
index 8af1a0f..210fa9c 100644
--- a/sp-saml-api/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/BrowserSSOProfileConfiguration.java
+++ b/sp-saml-api/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/BrowserSSOProfileConfiguration.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-saml-api/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/SAML2ProfileConfiguration.java b/sp-saml-api/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/SAML2ProfileConfiguration.java
index 9d2c77c..55f3f52 100644
--- a/sp-saml-api/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/SAML2ProfileConfiguration.java
+++ b/sp-saml-api/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/SAML2ProfileConfiguration.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-saml-api/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/SingleLogoutProfileConfiguration.java b/sp-saml-api/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/SingleLogoutProfileConfiguration.java
index fbcc8f6..4a1d087 100644
--- a/sp-saml-api/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/SingleLogoutProfileConfiguration.java
+++ b/sp-saml-api/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/SingleLogoutProfileConfiguration.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-saml-api/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/package-info.java b/sp-saml-api/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/package-info.java
index 41fda5b..e97e075 100644
--- a/sp-saml-api/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/package-info.java
+++ b/sp-saml-api/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/package-info.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-saml-impl/pom.xml b/sp-saml-impl/pom.xml
index ffc226b..a0db411 100644
--- a/sp-saml-impl/pom.xml
+++ b/sp-saml-impl/pom.xml
@@ -15,7 +15,7 @@
     <packaging>jar</packaging>
     
     <properties>
-        <checkstyle.configLocation>${project.basedir}/../resources/checkstyle.xml</checkstyle.configLocation>
+        <checkstyle.configLocation>${project.basedir}/../resources/checkstyle/checkstyle.xml</checkstyle.configLocation>
         <automatic.module.name>net.shibboleth.sp.saml.impl</automatic.module.name>
     </properties>
         
diff --git a/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/AbstractSAML2ArtifactConsumerProfileConfiguration.java b/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/AbstractSAML2ArtifactConsumerProfileConfiguration.java
index ed3a22c..8693b36 100644
--- a/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/AbstractSAML2ArtifactConsumerProfileConfiguration.java
+++ b/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/AbstractSAML2ArtifactConsumerProfileConfiguration.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/AbstractSAML2AssertionConsumerProfileConfiguration.java b/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/AbstractSAML2AssertionConsumerProfileConfiguration.java
index 8677ab7..343a5af 100644
--- a/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/AbstractSAML2AssertionConsumerProfileConfiguration.java
+++ b/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/AbstractSAML2AssertionConsumerProfileConfiguration.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/AbstractSAML2ProfileConfiguration.java b/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/AbstractSAML2ProfileConfiguration.java
index ea3a7cc..caa8026 100644
--- a/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/AbstractSAML2ProfileConfiguration.java
+++ b/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/AbstractSAML2ProfileConfiguration.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/BrowserSSOProfileConfiguration.java b/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/BrowserSSOProfileConfiguration.java
index 35e8ea7..b8a816c 100644
--- a/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/BrowserSSOProfileConfiguration.java
+++ b/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/BrowserSSOProfileConfiguration.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/SingleLogoutProfileConfiguration.java b/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/SingleLogoutProfileConfiguration.java
index 672bf22..4df4d22 100644
--- a/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/SingleLogoutProfileConfiguration.java
+++ b/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/SingleLogoutProfileConfiguration.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/package-info.java b/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/package-info.java
index 54278a5..5b08f92 100644
--- a/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/package-info.java
+++ b/sp-saml-impl/src/main/java/net/shibboleth/sp/saml/saml2/profile/config/impl/package-info.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-saml-impl/src/test/java/net/shibboleth/sp/saml/saml2/profile/config/impl/AbstractSAML2ProfileConfigurationTest.java b/sp-saml-impl/src/test/java/net/shibboleth/sp/saml/saml2/profile/config/impl/AbstractSAML2ProfileConfigurationTest.java
index 4c5d437..8cc1b1b 100644
--- a/sp-saml-impl/src/test/java/net/shibboleth/sp/saml/saml2/profile/config/impl/AbstractSAML2ProfileConfigurationTest.java
+++ b/sp-saml-impl/src/test/java/net/shibboleth/sp/saml/saml2/profile/config/impl/AbstractSAML2ProfileConfigurationTest.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-saml-impl/src/test/java/net/shibboleth/sp/saml/saml2/profile/config/impl/BrowserSSOProfileConfigurationTest.java b/sp-saml-impl/src/test/java/net/shibboleth/sp/saml/saml2/profile/config/impl/BrowserSSOProfileConfigurationTest.java
index e26e779..da854c3 100644
--- a/sp-saml-impl/src/test/java/net/shibboleth/sp/saml/saml2/profile/config/impl/BrowserSSOProfileConfigurationTest.java
+++ b/sp-saml-impl/src/test/java/net/shibboleth/sp/saml/saml2/profile/config/impl/BrowserSSOProfileConfigurationTest.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-saml-impl/src/test/java/net/shibboleth/sp/saml/saml2/profile/config/impl/SingleLogoutProfileConfigurationTest.java b/sp-saml-impl/src/test/java/net/shibboleth/sp/saml/saml2/profile/config/impl/SingleLogoutProfileConfigurationTest.java
index be5582d..a9d84b6 100644
--- a/sp-saml-impl/src/test/java/net/shibboleth/sp/saml/saml2/profile/config/impl/SingleLogoutProfileConfigurationTest.java
+++ b/sp-saml-impl/src/test/java/net/shibboleth/sp/saml/saml2/profile/config/impl/SingleLogoutProfileConfigurationTest.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-server-api/pom.xml b/sp-server-api/pom.xml
index 67e0bdb..61356e8 100644
--- a/sp-server-api/pom.xml
+++ b/sp-server-api/pom.xml
@@ -15,7 +15,7 @@
     <packaging>jar</packaging>
     
     <properties>
-        <checkstyle.configLocation>${project.basedir}/../resources/checkstyle.xml</checkstyle.configLocation>
+        <checkstyle.configLocation>${project.basedir}/../resources/checkstyle/checkstyle.xml</checkstyle.configLocation>
         <automatic.module.name>net.shibboleth.sp.server</automatic.module.name>
     </properties>
         
diff --git a/sp-server-api/src/main/java/net/shibboleth/sp/config/package-info.java b/sp-server-api/src/main/java/net/shibboleth/sp/config/package-info.java
index 160ee73..61ef139 100644
--- a/sp-server-api/src/main/java/net/shibboleth/sp/config/package-info.java
+++ b/sp-server-api/src/main/java/net/shibboleth/sp/config/package-info.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-server-api/src/main/java/net/shibboleth/sp/ddf/DDF.java b/sp-server-api/src/main/java/net/shibboleth/sp/ddf/DDF.java
index 86549ca..fc51abd 100644
--- a/sp-server-api/src/main/java/net/shibboleth/sp/ddf/DDF.java
+++ b/sp-server-api/src/main/java/net/shibboleth/sp/ddf/DDF.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-server-api/src/main/java/net/shibboleth/sp/ddf/DDFSupport.java b/sp-server-api/src/main/java/net/shibboleth/sp/ddf/DDFSupport.java
index 08add64..a007149 100644
--- a/sp-server-api/src/main/java/net/shibboleth/sp/ddf/DDFSupport.java
+++ b/sp-server-api/src/main/java/net/shibboleth/sp/ddf/DDFSupport.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-server-api/src/main/java/net/shibboleth/sp/ddf/RemotedHttpServletRequest.java b/sp-server-api/src/main/java/net/shibboleth/sp/ddf/RemotedHttpServletRequest.java
index 069d1ba..eb628fb 100644
--- a/sp-server-api/src/main/java/net/shibboleth/sp/ddf/RemotedHttpServletRequest.java
+++ b/sp-server-api/src/main/java/net/shibboleth/sp/ddf/RemotedHttpServletRequest.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-server-api/src/main/java/net/shibboleth/sp/ddf/RemotedHttpServletResponse.java b/sp-server-api/src/main/java/net/shibboleth/sp/ddf/RemotedHttpServletResponse.java
index 8960bb1..6bbf95a 100644
--- a/sp-server-api/src/main/java/net/shibboleth/sp/ddf/RemotedHttpServletResponse.java
+++ b/sp-server-api/src/main/java/net/shibboleth/sp/ddf/RemotedHttpServletResponse.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-server-api/src/main/java/net/shibboleth/sp/ddf/package-info.java b/sp-server-api/src/main/java/net/shibboleth/sp/ddf/package-info.java
index 28ca885..2526b58 100644
--- a/sp-server-api/src/main/java/net/shibboleth/sp/ddf/package-info.java
+++ b/sp-server-api/src/main/java/net/shibboleth/sp/ddf/package-info.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-server-api/src/test/java/net/shibboleth/sp/ddf/DDFSupportTest.java b/sp-server-api/src/test/java/net/shibboleth/sp/ddf/DDFSupportTest.java
index 3cb397a..bbf5eb1 100644
--- a/sp-server-api/src/test/java/net/shibboleth/sp/ddf/DDFSupportTest.java
+++ b/sp-server-api/src/test/java/net/shibboleth/sp/ddf/DDFSupportTest.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-server-api/src/test/java/net/shibboleth/sp/ddf/DDFTest.java b/sp-server-api/src/test/java/net/shibboleth/sp/ddf/DDFTest.java
index 095baac..61ca095 100644
--- a/sp-server-api/src/test/java/net/shibboleth/sp/ddf/DDFTest.java
+++ b/sp-server-api/src/test/java/net/shibboleth/sp/ddf/DDFTest.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-server-api/src/test/java/net/shibboleth/sp/ddf/RemotedHttpServletRequestTest.java b/sp-server-api/src/test/java/net/shibboleth/sp/ddf/RemotedHttpServletRequestTest.java
index 2470ebd..6689265 100644
--- a/sp-server-api/src/test/java/net/shibboleth/sp/ddf/RemotedHttpServletRequestTest.java
+++ b/sp-server-api/src/test/java/net/shibboleth/sp/ddf/RemotedHttpServletRequestTest.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-server-api/src/test/java/net/shibboleth/sp/ddf/RemotedHttpServletResponseTest.java b/sp-server-api/src/test/java/net/shibboleth/sp/ddf/RemotedHttpServletResponseTest.java
index 338ff2f..c3ac481 100644
--- a/sp-server-api/src/test/java/net/shibboleth/sp/ddf/RemotedHttpServletResponseTest.java
+++ b/sp-server-api/src/test/java/net/shibboleth/sp/ddf/RemotedHttpServletResponseTest.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-server-impl/pom.xml b/sp-server-impl/pom.xml
index 2a6ab6d..b969b3f 100644
--- a/sp-server-impl/pom.xml
+++ b/sp-server-impl/pom.xml
@@ -15,7 +15,7 @@
     <packaging>jar</packaging>
     
     <properties>
-        <checkstyle.configLocation>${project.basedir}/../resources/checkstyle.xml</checkstyle.configLocation>
+        <checkstyle.configLocation>${project.basedir}/../resources/checkstyle/checkstyle.xml</checkstyle.configLocation>
         <automatic.module.name>net.shibboleth.sp.server.impl</automatic.module.name>
     </properties>
         
diff --git a/sp-server-impl/src/main/java/net/shibboleth/sp/config/impl/package-info.java b/sp-server-impl/src/main/java/net/shibboleth/sp/config/impl/package-info.java
index 180de26..16fcca5 100644
--- a/sp-server-impl/src/main/java/net/shibboleth/sp/config/impl/package-info.java
+++ b/sp-server-impl/src/main/java/net/shibboleth/sp/config/impl/package-info.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-server-impl/src/main/java/net/shibboleth/sp/impl/OpenSAMLConfigBean.java b/sp-server-impl/src/main/java/net/shibboleth/sp/impl/OpenSAMLConfigBean.java
index 184249f..97c0ce2 100644
--- a/sp-server-impl/src/main/java/net/shibboleth/sp/impl/OpenSAMLConfigBean.java
+++ b/sp-server-impl/src/main/java/net/shibboleth/sp/impl/OpenSAMLConfigBean.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-server-impl/src/main/java/net/shibboleth/sp/remoting/impl/ReloadingEndpointManager.java b/sp-server-impl/src/main/java/net/shibboleth/sp/remoting/impl/ReloadingEndpointManager.java
index a62723a..5eefd68 100644
--- a/sp-server-impl/src/main/java/net/shibboleth/sp/remoting/impl/ReloadingEndpointManager.java
+++ b/sp-server-impl/src/main/java/net/shibboleth/sp/remoting/impl/ReloadingEndpointManager.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-server-impl/src/main/java/net/shibboleth/sp/spring/impl/ByteArrayToDDFConverter.java b/sp-server-impl/src/main/java/net/shibboleth/sp/spring/impl/ByteArrayToDDFConverter.java
index d0ff2b6..e61c7bb 100644
--- a/sp-server-impl/src/main/java/net/shibboleth/sp/spring/impl/ByteArrayToDDFConverter.java
+++ b/sp-server-impl/src/main/java/net/shibboleth/sp/spring/impl/ByteArrayToDDFConverter.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-server-impl/src/main/java/net/shibboleth/sp/spring/impl/DDFToByteArrayConverter.java b/sp-server-impl/src/main/java/net/shibboleth/sp/spring/impl/DDFToByteArrayConverter.java
index 2a67a6c..92cc4c7 100644
--- a/sp-server-impl/src/main/java/net/shibboleth/sp/spring/impl/DDFToByteArrayConverter.java
+++ b/sp-server-impl/src/main/java/net/shibboleth/sp/spring/impl/DDFToByteArrayConverter.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-server-impl/src/test/java/net/shibboleth/sp/remoting/endpoint/impl/XMLParserTest.java b/sp-server-impl/src/test/java/net/shibboleth/sp/remoting/endpoint/impl/XMLParserTest.java
index aa71283..075c70f 100644
--- a/sp-server-impl/src/test/java/net/shibboleth/sp/remoting/endpoint/impl/XMLParserTest.java
+++ b/sp-server-impl/src/test/java/net/shibboleth/sp/remoting/endpoint/impl/XMLParserTest.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-session-api/pom.xml b/sp-session-api/pom.xml
index 6818c7c..eed83a5 100644
--- a/sp-session-api/pom.xml
+++ b/sp-session-api/pom.xml
@@ -15,7 +15,7 @@
     <packaging>jar</packaging>
     
     <properties>
-        <checkstyle.configLocation>${project.basedir}/../resources/checkstyle.xml</checkstyle.configLocation>
+        <checkstyle.configLocation>${project.basedir}/../resources/checkstyle/checkstyle.xml</checkstyle.configLocation>
         <automatic.module.name>net.shibboleth.sp.session</automatic.module.name>
     </properties>
         
diff --git a/sp-session-api/src/main/java/net/shibboleth/sp/session/AbstractRemotableSPSession.java b/sp-session-api/src/main/java/net/shibboleth/sp/session/AbstractRemotableSPSession.java
index cd57e3b..8b72803 100644
--- a/sp-session-api/src/main/java/net/shibboleth/sp/session/AbstractRemotableSPSession.java
+++ b/sp-session-api/src/main/java/net/shibboleth/sp/session/AbstractRemotableSPSession.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-session-api/src/main/java/net/shibboleth/sp/session/RemotableSPSession.java b/sp-session-api/src/main/java/net/shibboleth/sp/session/RemotableSPSession.java
index a7efab2..b032737 100644
--- a/sp-session-api/src/main/java/net/shibboleth/sp/session/RemotableSPSession.java
+++ b/sp-session-api/src/main/java/net/shibboleth/sp/session/RemotableSPSession.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-session-api/src/main/java/net/shibboleth/sp/session/SPSession.java b/sp-session-api/src/main/java/net/shibboleth/sp/session/SPSession.java
index 38f950a..1478fc1 100644
--- a/sp-session-api/src/main/java/net/shibboleth/sp/session/SPSession.java
+++ b/sp-session-api/src/main/java/net/shibboleth/sp/session/SPSession.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-session-api/src/main/java/net/shibboleth/sp/session/SessionException.java b/sp-session-api/src/main/java/net/shibboleth/sp/session/SessionException.java
index 65c955e..d0a43e6 100644
--- a/sp-session-api/src/main/java/net/shibboleth/sp/session/SessionException.java
+++ b/sp-session-api/src/main/java/net/shibboleth/sp/session/SessionException.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-session-api/src/main/java/net/shibboleth/sp/session/package-info.java b/sp-session-api/src/main/java/net/shibboleth/sp/session/package-info.java
index ae1c4b6..774513a 100644
--- a/sp-session-api/src/main/java/net/shibboleth/sp/session/package-info.java
+++ b/sp-session-api/src/main/java/net/shibboleth/sp/session/package-info.java
@@ -1,10 +1,7 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
- * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
- * compliance with the License.  You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/sp-session-impl/pom.xml b/sp-session-impl/pom.xml
index 1487723..65b7e54 100644
--- a/sp-session-impl/pom.xml
+++ b/sp-session-impl/pom.xml
@@ -15,7 +15,7 @@
     <packaging>jar</packaging>
     
     <properties>
-        <checkstyle.configLocation>${project.basedir}/../resources/checkstyle.xml</checkstyle.configLocation>
+        <checkstyle.configLocation>${project.basedir}/../resources/checkstyle/checkstyle.xml</checkstyle.configLocation>
         <automatic.module.name>net.shibboleth.sp.session.impl</automatic.module.name>
     </properties>
         
diff --git a/sp-testing/pom.xml b/sp-testing/pom.xml
index 843aa7f..da7c506 100644
--- a/sp-testing/pom.xml
+++ b/sp-testing/pom.xml
@@ -15,7 +15,7 @@
     <packaging>jar</packaging>
     
     <properties>
-        <checkstyle.configLocation>${project.basedir}/../resources/checkstyle.xml</checkstyle.configLocation>
+        <checkstyle.configLocation>${project.basedir}/../resources/checkstyle/checkstyle.xml</checkstyle.configLocation>
         <automatic.module.name>net.shibboleth.sp.testing</automatic.module.name>
     </properties>
         

diff --git a/sp-server-api/src/main/java/net/shibboleth/sp/Application.java b/sp-server-api/src/main/java/net/shibboleth/sp/Application.java
index b177834..ca6c072 100644
--- a/sp-server-api/src/main/java/net/shibboleth/sp/Application.java
+++ b/sp-server-api/src/main/java/net/shibboleth/sp/Application.java
@@ -18,12 +18,13 @@ package net.shibboleth.sp;
 import javax.annotation.Nonnull;
 import javax.annotation.concurrent.ThreadSafe;
 
+import org.opensaml.profile.context.ProfileRequestContext;
 import org.opensaml.saml.metadata.resolver.MetadataResolver;
 
 import net.shibboleth.idp.attribute.filter.AttributeFilter;
 import net.shibboleth.idp.attribute.resolver.AttributeResolver;
 import net.shibboleth.idp.attribute.transcoding.AttributeTranscoderRegistry;
-import net.shibboleth.profile.relyingparty.RelyingPartyConfigurationResolver;
+import net.shibboleth.profile.relyingparty.RelyingPartyConfiguration;
 import net.shibboleth.shared.annotation.constraint.NotEmpty;
 import net.shibboleth.shared.component.IdentifiedComponent;
 import net.shibboleth.shared.service.ServiceException;
@@ -50,16 +51,14 @@ public interface Application extends IdentifiedComponent, Endpoint {
     @Nonnull @NotEmpty static String COMPONENT = "this";
     
     /**
      * Get {@link RelyingPartyConfigurationResolver} for this {@link Application}.
      * 
-     * <p>The component is returned in a locked state and must be closed by the caller.</p>
-     * 
-     * @return the {@link RelyingPartyConfigurationResolver} to use
+     * @param profileRequestContext current profile request context
      * 
-     * @throws ServiceException if no instance can be obtained
+     * @return the applicable configuration
      */
-    @Nonnull ServiceableComponent<RelyingPartyConfigurationResolver> getRelyingPartyConfigurationResolver()
-            throws ServiceException;
+    @Nonnull RelyingPartyConfiguration getRelyingPartyConfiguration(
+            @Nonnull final ProfileRequestContext profileRequestContext);
     
     /**
      * Get {@link MetadataResolver} for this {@link Application}.
@@ -50,16 +51,14 @@ public interface Application extends IdentifiedComponent, Endpoint {
     
     /**
-     * Get {@link RelyingPartyConfigurationResolver} for this {@link Application}.
+     * Get the {@link RelyingPartyConfiguration} applicable to the request.
      * 
diff --git a/sp-server-impl/src/main/java/net/shibboleth/sp/impl/BasicApplication.java b/sp-server-impl/src/main/java/net/shibboleth/sp/impl/BasicApplication.java
index 1c9c6d5..f9652c9 100644
--- a/sp-server-impl/src/main/java/net/shibboleth/sp/impl/BasicApplication.java
+++ b/sp-server-impl/src/main/java/net/shibboleth/sp/impl/BasicApplication.java
@@ -15,17 +15,24 @@
 
 package net.shibboleth.sp.impl;
 
+import java.util.Collection;
+import java.util.List;
+
 import javax.annotation.Nonnull;
+import javax.annotation.Nullable;
 
+import org.opensaml.profile.context.ProfileRequestContext;
 import org.opensaml.saml.metadata.resolver.MetadataResolver;
 import org.slf4j.Logger;
 
 import net.shibboleth.idp.attribute.filter.AttributeFilter;
 import net.shibboleth.idp.attribute.resolver.AttributeResolver;
 import net.shibboleth.idp.attribute.transcoding.AttributeTranscoderRegistry;
-import net.shibboleth.profile.relyingparty.RelyingPartyConfigurationResolver;
+import net.shibboleth.profile.relyingparty.BasicRelyingPartyConfiguration;
+import net.shibboleth.profile.relyingparty.RelyingPartyConfiguration;
 import net.shibboleth.shared.annotation.constraint.NonnullAfterInit;
 import net.shibboleth.shared.annotation.constraint.NotEmpty;
+import net.shibboleth.shared.collection.CollectionSupport;
 import net.shibboleth.shared.component.ComponentInitializationException;
 import net.shibboleth.shared.logic.Constraint;
 import net.shibboleth.shared.primitive.LoggerFactory;
@@ -33,26 +40,26 @@ import net.shibboleth.shared.service.ReloadableService;
 import net.shibboleth.shared.service.ServiceException;
 import net.shibboleth.shared.service.ServiceableComponent;
 import net.shibboleth.sp.Application;
-import net.shibboleth.sp.remoting.AbstractEndpoint;
 import net.shibboleth.sp.remoting.ApplicationEndpoint;
 import net.shibboleth.sp.remoting.ApplicationEndpointManager;
+import net.shibboleth.sp.remoting.Endpoint;
 import net.shibboleth.sp.remoting.RemoteProcessingException;
 import net.shibboleth.sp.ddf.DDF;
 
 /**
  * Basic implementation of an {@link Application}.
  */
-public class BasicApplication extends AbstractEndpoint implements Application {
+public class BasicApplication extends BasicRelyingPartyConfiguration implements Application, Endpoint {
 
     /** Class logger. */
     @Nonnull private final Logger log = LoggerFactory.getLogger(BasicApplication.class);
 
+    /** Installed relying party configuration "overrides". */
+    @Nonnull private Collection<RelyingPartyConfiguration> relyingPartyConfigurations;
+    
     /** Component endpoints. */
     @NonnullAfterInit private ApplicationEndpointManager endpointManager;
     
-    /** AssertingParty resolver. */
-    @NonnullAfterInit private ReloadableService<RelyingPartyConfigurationResolver> relyingPartyConfigurationResolver;
-    
     /** Metadata source. */
     @NonnullAfterInit private ReloadableService<MetadataResolver> metadataResolver;
     
@@ -65,6 +72,11 @@ public class BasicApplication extends AbstractEndpoint implements Application {
     /** Attribute filter. */
     @NonnullAfterInit private ReloadableService<AttributeFilter> attributeFilter;
     
+    /** Constructor. */
+    public BasicApplication() {
+        relyingPartyConfigurations = CollectionSupport.emptyList();
+    }
+    
     /**
      * Sets the {@link ApplicationEndpointManager} to use.
      * 
@@ -90,23 +102,33 @@ public class BasicApplication extends AbstractEndpoint implements Application {
     @Nonnull @NotEmpty public String getAddress() {
         return getId();
     }
-    
+
     /** {@inheritDoc} */
-    @Nonnull public ServiceableComponent<RelyingPartyConfigurationResolver> getRelyingPartyConfigurationResolver()
-            throws ServiceException {
-        return relyingPartyConfigurationResolver.getServiceableComponent();
+    @Nonnull public RelyingPartyConfiguration getRelyingPartyConfiguration(
+            @Nonnull ProfileRequestContext profileRequestContext) {
+        
+        for (final RelyingPartyConfiguration rpc : relyingPartyConfigurations) {
+            if (rpc.test(profileRequestContext)) {
+                return rpc;
+            }
+        }
+        
+        return this;
     }
     
     /**
      * Set the {@link RelyingPartyConfigurationResolver} to use.
      * 
-     * @param service asserting party resolver service
+     * @param configs relying party configuration overrides
      */
-    public void setAssertingPartyResolver(@Nonnull final ReloadableService<RelyingPartyConfigurationResolver> service) {
-        relyingPartyConfigurationResolver = Constraint.isNotNull(service,
-                "RelyingPartyConfigurationResolver service cannot be null");
+    public void setRelyingPartyConfigurations(@Nullable final List<RelyingPartyConfiguration> configs) {
+        if (configs != null) {
+            relyingPartyConfigurations = CollectionSupport.copyToList(configs);
+        } else {
+            relyingPartyConfigurations = CollectionSupport.emptyList();
+        }
     }
-
+    
     /** {@inheritDoc} */
     @Nonnull public ServiceableComponent<MetadataResolver> getMetadataResolver() throws ServiceException {
         return metadataResolver.getServiceableComponent();
@@ -173,9 +195,9 @@ public class BasicApplication extends AbstractEndpoint implements Application {
     }
 
     /** {@inheritDoc} */
-    @Override
-    @Nonnull public DDF doReceive(@Nonnull final DDF input) throws RemoteProcessingException {
+    @Nonnull public DDF receive(@Nonnull final DDF input) throws RemoteProcessingException {
         checkComponentActive();
+        Constraint.isTrue(getAddress().equals(input.name()), "Address was invalid");
         
         final String component = input.getmember(COMPONENT).string();
         if (component == null || component.isEmpty()) {
@@ -90,23 +102,33 @@ public class BasicApplication extends AbstractEndpoint implements Application {
     
     /**
-     * Set the {@link RelyingPartyConfigurationResolver} to use.
+     * Sets the {@link RelyingPartyConfiguration}s to include.
      * 
-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list